==> knative-model-4.12.0-sources.jar: io/fabric8/knative/sources/v1beta1/SinkBindingSpecBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SinkBindingSpecBuilder extends SinkBindingSpecFluentImpl<SinkBindingSpecBuilder> implements VisitableBuilder<SinkBindingSpec,SinkBindingSpecBuilder> {

    SinkBindingSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SinkBindingSpecBuilder() { 
        this(true);
    }


    public SinkBindingSpecBuilder(Boolean validationEnabled) { 
        this(new SinkBindingSpec(), validationEnabled);
    }


    public SinkBindingSpecBuilder(SinkBindingSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public SinkBindingSpecBuilder(SinkBindingSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new SinkBindingSpec(), validationEnabled);
    }


    public SinkBindingSpecBuilder(SinkBindingSpecFluent<?> fluent,SinkBindingSpec instance) { 
        this(fluent, instance, true);
    }


    public SinkBindingSpecBuilder(SinkBindingSpecFluent<?> fluent,SinkBindingSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withCeOverrides(instance.getCeOverrides()); 
        fluent.withSink(instance.getSink()); 
        fluent.withSubject(instance.getSubject()); 
        this.validationEnabled = validationEnabled; 
    }


    public SinkBindingSpecBuilder(SinkBindingSpec instance) { 
        this(instance,true);
    }


    public SinkBindingSpecBuilder(SinkBindingSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withCeOverrides(instance.getCeOverrides()); 
        this.withSink(instance.getSink()); 
        this.withSubject(instance.getSubject()); 
        this.validationEnabled = validationEnabled; 
    }


    public SinkBindingSpec build() {
        SinkBindingSpec buildable = new SinkBindingSpec(fluent.getCeOverrides(),fluent.getSink(),fluent.getSubject());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SinkBindingSpecBuilder that = (SinkBindingSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/sources/v1beta1/SinkBindingSpecBuilder.java <==
package io.fabric8.knative.sources.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SinkBindingSpecBuilder extends SinkBindingSpecFluentImpl<SinkBindingSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<SinkBindingSpec,SinkBindingSpecBuilder> {

    SinkBindingSpecFluent<?> fluent;
    Boolean validationEnabled;

    public SinkBindingSpecBuilder() {
        this(true);
    }

    public SinkBindingSpecBuilder(Boolean validationEnabled) {
        this(new SinkBindingSpec(), validationEnabled);
    }

    public SinkBindingSpecBuilder(SinkBindingSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public SinkBindingSpecBuilder(SinkBindingSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SinkBindingSpec(), validationEnabled);
    }

    public SinkBindingSpecBuilder(SinkBindingSpecFluent<?> fluent,SinkBindingSpec instance) {
        this(fluent, instance, true);
    }

    public SinkBindingSpecBuilder(SinkBindingSpecFluent<?> fluent,SinkBindingSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withCeOverrides(instance.getCeOverrides()); 
        fluent.withSink(instance.getSink()); 
        fluent.withSubject(instance.getSubject()); 
        this.validationEnabled = validationEnabled; 
    }

    public SinkBindingSpecBuilder(SinkBindingSpec instance) {
        this(instance,true);
    }

    public SinkBindingSpecBuilder(SinkBindingSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withCeOverrides(instance.getCeOverrides()); 
        this.withSink(instance.getSink()); 
        this.withSubject(instance.getSubject()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.sources.v1beta1.EditableSinkBindingSpec build() {
        EditableSinkBindingSpec buildable = new EditableSinkBindingSpec(fluent.getCeOverrides(),fluent.getSink(),fluent.getSubject());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SinkBindingSpecBuilder that = (SinkBindingSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
